---
title: 'antispam:plugin:phishing'
url: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-phishing'
markdown: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-phishing.md'
date: '2026-09-22'
description: 'Check URIs against Openphish and PhishTank phishing feeds. warden --task=antispam:plugin:phishing Option Value Default Description --phishing_openphish_feed <string> /etc/mail/spamassassin/openphish-feed.txt The path to where to save the Openphish feed. The free Openphish feed is updated …'
taxonomy:
  category:
    - docs
  tag:
    - phishing
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antispam       antispam:plugin:phishing    

# antispam:plugin:phishing

Check URIs against Openphish and PhishTank phishing feeds.

```
warden --task=antispam:plugin:phishing
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--phishing_openphish_feed` | <string> | /etc/mail/spamassassin/openphish-feed.txt | The path to where to save the Openphish feed. The free Openphish feed is updated every 6 hours and will be automatically downloaded from <https://openphish.com/feed.txt>. |
| `--phishing_phishtank_feed` | <string> | /etc/mail/spamassassin/phishtank-feed.csv | The path to where to save the PhishTank feed. The free PhishTank feed is updated every 3 hours with an API key or every 6 hours without and will be automatically downloaded from <https://data.phishtank.com/data/online-valid.csv>. |
| `--phishing_phishtank_apikey` | <string> |  | The PhishTank API application key. Sign up for the application key at: [https://www.phishtank.com/api\_register.php](https://www.phishtank.com/api_register.php) |
| `--uri_phishing_score` | <string> | 100.0 | The score to apply to the `URI_PHISHING` rule. This rule with match when a URL matches a phishing URL in one of the phishing feeds. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// set the phishing_phishtank_apikey
warden --task=antispam:plugin:phishing --phishing_phishtank_apikey=XXXXXXXXXX --reload=yes

// reset phishing_phishtank_apikey to its default value
warden --task=antispam:plugin:phishing --default_option=phishing_phishtank_apikey --reload=yes

// reset all settings to their default values
warden --task=antispam:plugin:phishing --default=yes --reload=yes
```

## Related Pages

- [Phishing Settings](https://docs.danami.com/warden/settings/antispam/plugin-settings/phishing "Phishing Settings")
- [Phishing](https://docs.danami.com/warden/user-guide/antispam-plugins/phishing "Phishing")

 [ ](https://docs.danami.com/warden/user-guide/antispam-plugins/phishing) [](https://docs.danami.com/warden/settings/antispam/plugin-settings/phishing)

---

## Navigation

- Previous: [antispam:plugin:olevbmacro](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-olevbmacro.md)
- Next: [antispam:plugin:pyzor](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-pyzor.md)
